@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhrcfile.pl 2.11 99/08/13 22:17:26
+##	@(#) mhrcfile.pl 2.13 00/02/13 03:28:50
 ##  Author:
 ##      Earl Hood       mhonarc@pobox.com
 ##  Description:
@@ -417,6 +417,26 @@ sub read_resource_file {
 	    }
 	    last FMTSW;
 	}
+	if ($elem eq "mimedecoders") {		# Mime decoders
+	    if ($override) {
+		%readmail::MIMEDecoders = ();
+		%readmail::MIMEDecodersSrc = ();
+	    }
+	    while (defined($line = <$handle>)) {
+		last  if     $line =~ /^\s*<\/mimedecoders\s*>/i;
+		next  unless $line =~ /\S/;
+		$line =~ s/\s//g;
+		if ($line =~ /;/) {	# using Perl 5 qualification
+		    ($type,$routine,$plfile) = split(/;/,$line,3);
+		} else {
+		    ($type,$routine,$plfile) = split(/:/,$line,3);
+		}
+		$type =~ tr/A-Z/a-z/;
+		$readmail::MIMEDecoders{$type}    = $routine;
+		$readmail::MIMEDecodersSrc{$type} = $plfile  if $plfile =~ /\S/;
+	    }
+	    last FMTSW;
+	}
 	if ($elem eq "mimefilters") {		# Mime filters
 	    if ($override) {
 		%readmail::MIMEFilters = ();
@@ -972,6 +992,10 @@ sub read_resource_file {
 	if ($elem eq "usinglastpg") {
 	    $UsingLASTPG = 1; last FMTSW;
 	}
+	if ($elem eq "varregex") {		# Regex matching rc vars
+	    $VarExp = &get_elem_last_line($handle, $elem);
+	    last FMTSW;
+	}
 	if ($elem eq "weekdays") {		# Full weekday name
 	    @a = &get_list_content($handle, $elem);
 	    if (scalar(@a)) {
@@ -1044,7 +1068,7 @@ sub get_list_content {
 	last  if /^\s*<\/$gi\s*>/i;
 	next  unless /\S/;
 	s/\r?\n?$//;
-	push(@items, split(/[:;]/, $_));
+	push(@items, split(/[:]/, $_));
     }
     @items;
 }
